##### Interview study 
#
# Author: Felix Dreger
#
# Data Analysis:  Driver behaviour merging onto the highway
# DataSet: ParticipantData.xlsx
#
# content:
#           - Demographic data
#           - Analysis Driver assistance system use
#           - Analysis Driver merging steps
#	
#      
# Packages:
library("foreign", lib.loc="~/R/R-3.4.1/library")
library("lattice", lib.loc="~/R/R-3.4.1/library")
library("xlsx")
library("psych")
library("Hmisc")
library("corrgram")
library("stargazer")
library("reshape2")
library("ez")
library("ggplot2")
library("RColorBrewer")
library("reshape")
library("scales")
library("png")
library("grid")


####################### set working directory (workspace) ################################
######################                                    #################################

rm(list=ls())


setwd("D:/...")

##################### Import of data ########################################################

demographicDat <- read.xlsx2("ParticipantData.xlsx",sheetIndex = 1, header = T, startRow =2, endRow = 17 )


#################################### Data overview          #####################################################
####################################                        ####################################################

summary(demographicDat)


####################################################### ADAS questionnaire  analysis  ##############################################
#######################################################                               ##############################################


######## subset data
ColHeadADAS<-colnames(demographicDat)[1:12]
AdasQuestionnaire<-as.matrix(subset(demographicDat, select= ColHeadADAS))

########################################################  how many systems are rated ########################################################################

ogicAdasQuestionnaire<-AdasQuestionnaire != 0
FilledRows<-rowSums(LogicAdasQuestionnaire[,2:12])


####################################################### create data set with participant ID as numeric matrix #############################################
NewADASQuestionnaire<-cbind(AdasQuestionnaire,FilledRows)

Adas_List_numeric<-lapply(NewADASQuestionnaire, as.numeric)


Numeric_Adas_Questionnaire<- matrix(unlist(Adas_List_numeric), nrow=nrow(NewADASQuestionnaire), byrow=F)
NewOldNamens<-colnames(NewADASQuestionnaire)

colnames(Numeric_Adas_Questionnaire)<-NewOldNamens


###################################################### RowSums of ADAS calculated ########################################################################


RowSumsADASQuestionnaire<-rowSums(Numeric_Adas_Questionnaire[,grep("ACC", colnames(Numeric_Adas_Questionnaire)):grep("AM", colnames(Numeric_Adas_Questionnaire))])

AddADASQuestionnaire<-cbind(Numeric_Adas_Questionnaire,RowSumsADASQuestionnaire)



###################################################### Means of only filled items/ proportion corrected #################################################


Pc_Mean<-AddADASQuestionnaire[, grep("RowSumsADASQuestionnaire", colnames(AddADASQuestionnaire))] / AddADASQuestionnaire[, grep("FilledRows", colnames(AddADASQuestionnaire))]


Pc_Mean_AddADASQuestionnaire<-cbind(AddADASQuestionnaire,Pc_Mean)

### "normal" means neglecting what has been filled or not

RM_ADAS<-rowMeans(Pc_Mean_AddADASQuestionnaire[,grep("ACC", colnames(Pc_Mean_AddADASQuestionnaire)):grep("AM", colnames(Pc_Mean_AddADASQuestionnaire))])

RM_PCM_AddADASQuestionnaire<-cbind(Pc_Mean_AddADASQuestionnaire,RM_ADAS) #attach to frame


################ SD not proportion corrected

Participant_SD_ADAS    <-apply((RM_PCM_AddADASQuestionnaire[,2:12]), 1, sd)
ADAS_SD_System         <-apply((RM_PCM_AddADASQuestionnaire[,2:12]), 2, sd)


############### Mean not proportion coreceted

Participant_Mean_ADAS    <-apply((RM_PCM_AddADASQuestionnaire[,2:12]), 1, mean)     #### similar to rowmeans above/ not proportion corrected/ PC above
ADAS_Mean_System         <-apply((RM_PCM_AddADASQuestionnaire[,2:12]), 2, mean)



############## proportion corrected
Dat_ADAS_Mean_PC<-RM_PCM_AddADASQuestionnaire

#### creates logic ADAS questionnaire to check which columns above 0 so which systems are used (drivers never reported 0 use)

LogicAdasQuestionnaire_ADASCol<-AdasQuestionnaire != 0
FilledColsADAS<-colSums(LogicAdasQuestionnaire_ADASCol[,2:12])

########################

Dat_ADAS_Mean_PC[Dat_ADAS_Mean_PC == 0]<-NA # index only for matrix or frames not for vectors

### proportion corrected mean 
ADAS_PC_Mean_System   <-apply((Dat_ADAS_Mean_PC[,2:12]), 2, mean, na.rm =T)
ADAS_PC_SD_System     <-apply((Dat_ADAS_Mean_PC[,2:12]), 2, sd, na.rm =T)


# two system never in truck or mentioned only by one driver therefore no SD set to 0 to be comupted

ADAS_PC_SD_System[is.na(ADAS_PC_SD_System)]<-0

PerADAS_SE            <-ADAS_PC_SD_System/sqrt(length(ADAS_PC_SD_System))



######attach SD of rowMeans 


SD_RM_PCM_Dat<-cbind(RM_PCM_AddADASQuestionnaire,Participant_SD_ADAS)
Participant_Pc_SD_ADAS<-apply((RM_PCM_AddADASQuestionnaire[,2:12]), 1, sd)


###################### frequecy tables 
Freq_ACC<-xtabs(SD_RM_PCM_Dat[,2]~SD_RM_PCM_Dat[,1], SD_RM_PCM_Dat)

################## reshape to long format to plot desired table

LongDat<-melt(SD_RM_PCM_Dat [,2:12], id.vars= SD_RM_PCM_Dat [,1])

colnames(LongDat)<-c(colnames(SD_RM_PCM_Dat)[1], "ADAS","Rating")

#nb.types   <- nlevels(df.merged$Type)
#nb.methods <- nlevels(df.merged$Method)

################################### Plot rating ##########################################################
##################################              ##########################################################

## not used

'ylabelss <- expression(atop(bold("Rating"), scriptstyle("0 = never; 9 = Very often")))

### alternative to  labels on top "Rating \n (\tiny 0 = Almost never; 9 = Very often)"

png("RatingPerDriverPerADAS.png", width= 700, height = 700) 

ggplot(LongDat, aes(x= ADAS, y=Rating, fill=factor(ParticipantNr.))) + 
geom_bar(stat="identity", position=position_dodge(width = 0.5), 
show.legend = T)+  scale_fill_grey()+  scale_x_discrete(name="Driver Assistance Systems", 
labels= c("ACC","FCW","LDW","LKA","CC","LCA","CMS","WIS","AEB","FL","AM"))+ scale_y_continuous(name=ylabelss, 
breaks =  seq(0, 10, by = 1)) + ggtitle("Driver assistance systems use by driver")+
theme(plot.title = element_text(hjust = 0.5))+ labs(fill= "Participant")+ theme(axis.title.y = 
element_text(size = "12"))+theme(plot.margin = unit(c(2,2,2,2), "cm")) 

dev.off()'

################################# Plot mean rating by participant ##############################################################
#################################          Analysis + Plot        ##############################################################


NA_ADAS_Dat<-SD_RM_PCM_Dat [,1:12]

NA_ADAS_Dat[NA_ADAS_Dat == 0]<-NA
SD_PC_mean<- apply((NA_ADAS_Dat[,2:12]), 1, sd, na.rm=T)
PerParticipant_SE <-  SD_PC_mean/sqrt(length(SD_PC_mean))


SD_RM_PCM_PcSD_Dat<-cbind(SD_RM_PCM_Dat,SD_PC_mean,PerParticipant_SE)

#LongDatMeanRating<-melt(SD_RM_PCM_PcSD_Dat [,2:12], id.vars= SD_RM_PCM_Dat [,1])

SD_RM_PCM_PcSD_Dat<-as.data.frame(SD_RM_PCM_PcSD_Dat)

ylabel <- expression(atop(displaystyle(bold("Pc mean rating")), scriptstyle("0 = never; 9 = Very often"),cex = 20))

png("ADASRatingPerPart.png", width = 1000, height = 1000)

ggplot(SD_RM_PCM_PcSD_Dat, aes(x= as.factor(ParticipantNr.), y=Pc_Mean)) + 
geom_bar(stat="identity")+  
scale_fill_grey()+  
scale_x_discrete( labels= c(1:15), breaks =  seq(1, 15, by = 1))+ 
xlab("Driver")+
scale_y_continuous( breaks =  seq(0, 10, by = 1), limits = c(0,10)) +
ylab(ylabel)+ 
ggtitle("Advanced driver assistance systems use by driver")+
theme(plot.title = element_text(hjust = 0.5))+ 
labs(fill= "Participant")+ 
theme(axis.title.y = element_text(size = "22", margin = margin(r = 20)), axis.text= element_text(size = "16"))+
theme(axis.title.x = element_text(size = "22", margin = margin(t = 20)), axis.text= element_text(size = "16"))+
theme(plot.title        = element_text(size = "22"))+
theme(plot.margin  = unit(c(2,2,2,2), "cm"))+
geom_errorbar(aes(ymin=Pc_Mean- PerParticipant_SE,ymax=Pc_Mean+PerParticipant_SE),width=.2)+
geom_text(aes(label=FilledRows), vjust=20.0, color="white", size=3.5)


dev.off()

######################## mean rating by Assitance System ########################################################
########################          Analysis + Plot        ########################################################

NamesOfADAS<-colnames(SD_RM_PCM_PcSD_Dat)[2:12]
ADAS_Mean_SD<-cbind(NamesOfADAS,as.vector(ADAS_PC_Mean_System),as.vector(ADAS_SD_System),as.vector(PerADAS_SE))


ADAS_Mean_SD<-as.data.frame(ADAS_Mean_SD, row.names = F)

ADAS_Mean_SD$V2<-round(sapply(sapply(ADAS_Mean_SD$V2,as.character), as.numeric),3)
ADAS_Mean_SD$V3<-sapply(sapply(ADAS_Mean_SD$V3,as.character), as.numeric)

png("MeanRatingADAS.png", width = 1000, height = 1000)

ggplot(ADAS_Mean_SD, aes(x= factor(NamesOfADAS, levels= c("ACC","FCW","LDP","LKA","CC","BSA","CMS","WIS","EB","FL","AM")), y= V2))+ 
geom_bar(stat="identity")+  scale_fill_grey()+
scale_x_discrete(labels= c( "ACC","FCW","LDW","LKA","CC","LCA","CMS","WIS","AEB","FL","AM"))+ 
xlab("Advanced driver assistance systems")+
ylab(ylabel)+
scale_y_continuous(breaks =  seq(0, 10, by = 1), limits = c(0,10))+ 
ggtitle("Advanced driver assistance systems use by system")+
theme(plot.title = element_text(hjust = 0.5))+ 
labs(fill= "Driver")+ 
theme(axis.title.y = element_text(size = "22", margin = margin(r = 20)), axis.text= element_text(size = "16"))+
theme(axis.title.x = element_text(size = "22", margin = margin(t = 20)), axis.text= element_text(size = "16"))+
theme(plot.title        = element_text(size = "22"))+
theme(plot.margin  = unit(c(2,2,2,2), "cm")) +
geom_errorbar(aes(ymin=V2-PerADAS_SE,ymax=V2+PerADAS_SE),width=.2)+
geom_text(aes(label=FilledColsADAS), vjust=15.0, color="white", size=3.5)

dev.off()

#geom_text(aes(label=FilledRows), vjust=20.0, color="white", size=3.5)
#breaks =  seq(1, 11, by = 1)

############################## Years of Driving #################################################################


Mean_Exp<-mean(as.numeric(as.character(demographicDat$Years.of.Driving)))
SD_Exp<-sd(as.numeric(as.character(demographicDat$Years.of.Driving)))



############################# Age ###################################################################

Mean_Age<-mean(as.numeric(as.character(demographicDat$Age)))
SD_Age<-sd(as.numeric(as.character(demographicDat$Age)))

########################## Mileage ##################################################################


Median_Mielage<-median(as.numeric(as.character(demographicDat$Mileage)))
Range_Mileage<-range(as.numeric(as.character(demographicDat$Mileage)))


########################## Freeway time ##################################################################

Median_Freeway.time<-median(as.numeric(as.character(demographicDat$Freeway.time)))
Range_Freeway.time<-range(as.numeric(as.character(demographicDat$Freeway.time)))


######################### System Location ################################################


 #unlist the string or better say extract the second number in string

Rank1<-sapply(strsplit(as.character(demographicDat$SYSTEM.Location), "\\,"), "[[", 1) #unlist the string or better say extract the second number in string
Rank2<-sapply(strsplit(as.character(demographicDat$SYSTEM.Location), "\\,"), "[[", 2)
Rank3<-sapply(strsplit(as.character(demographicDat$SYSTEM.Location), "\\,"), "[[", 3)


DemGrDat<-cbind(demographicDat,Rank1,Rank2,Rank3)

###################################### dataframe prep for Ranking ########################################################################

j<-as.numeric(as.character(DemGrDat [,1]))
DatRanking<-DemGrDat[,grep("Rank1", colnames(DemGrDat)):grep("Rank3", colnames(DemGrDat))]

NewRank2<-gsub( pattern = 0, replacement = "Not assigned rank", DatRanking$Rank2)
NewRank3<-gsub( pattern = 0, replacement = "Not assigned rank", DatRanking$Rank3)

DatRanking$Rank2<-NewRank2
DatRanking$Rank3<-NewRank3

CoerceRankCharac<-sapply(DatRanking,as.character)

LongFormRanking<-melt(CoerceRankCharac, id.vars= j)

colnames(LongFormRanking)<-c(colnames(DemGrDat)[1], "Ranking","Location")

################# ranking/ overall best ########################################################################################
#################                       ########################################################################################   

## First check data (not used)

freqTabRank1<-xtabs(~DatRanking$Rank1)
freqTabRank2<-xtabs(~DatRanking$Rank2)
freqTabRank3<-xtabs(~DatRanking$Rank3)

freqTabRank1_df<-as.data.frame(freqTabRank1)
freqTabRank2_df<-as.data.frame(freqTabRank2)
freqTabRank3_df<-as.data.frame(freqTabRank3)

names(freqTabRank1_df)[1]<- "location"
names(freqTabRank2_df)[1]<- "location"
names(freqTabRank3_df)[1]<- "location"

freqTabRank1_df[order(freqTabRank1_df$Freq, decreasing = T),]
freqTabRank2_df[order(freqTabRank2_df$Freq, decreasing = T),]
freqTabRank3_df[order(freqTabRank3_df$Freq, decreasing = T),]

IntermediatextabsfreqRank<-merge(freqTabRank1_df, freqTabRank2_df, by = 0, all = TRUE)[-1]
FinalFreqRankDf         <-merge (IntermediatextabsfreqRank,freqTabRank2_df, by = 0, all = T)[-1]

FinalFreqRankDf[order(FinalFreqRankDf$Freq.x,FinalFreqRankDf$Freq.y,FinalFreqRankDf$Freq, decreasing = T),]
FinalFreqRankDf[order(FinalFreqRankDf$location.x,FinalFreqRankDf$location.y,FinalFreqRankDf$location, decreasing = T),]

#######################################################
######################################################


FinalFreqRankDf[is.na(FinalFreqRankDf)]<- 0
levels(FinalFreqRankDf$location.y)[levels(FinalFreqRankDf$location.y)== " steering wheel"] <- "10"
levels(FinalFreqRankDf$location)  [levels(FinalFreqRankDf$location)  == " steering wheel"] <- "10"

levels(FinalFreqRankDf$location.y)[levels(FinalFreqRankDf$location.y)== "Not assigned rank"] <- "11"
levels(FinalFreqRankDf$location)  [levels(FinalFreqRankDf$location)  == "Not assigned rank"] <- "11"

levels(FinalFreqRankDf$location.x)[levels(FinalFreqRankDf$location.x)== "NA"] <- "0"

FinalFreqRankDf$Freq.x.Weighted<-FinalFreqRankDf$Freq.x*3 
FinalFreqRankDf$Freq.y.Weighted<-FinalFreqRankDf$Freq.y*2
FinalFreqRankDf$Freq.Weighted  <-FinalFreqRankDf$Freq*1



FinalFreqRankDf$SoW<-rowSums(FinalFreqRankDf[,c(7,8,9)]) ## check order of locations


str(FinalFreqRankDf)


###########################################   bar chart  ###########################################
## Not used
'

png("LocationPerparticipantPerRank.png")

ggplot(LongFormRanking, aes(x= Ranking, y=Location, fill=factor(ParticipantNr.))) + 
geom_bar(stat="identity", position=position_dodge(width = 0.5), 
show.legend = T)+  scale_fill_grey()+  scale_x_discrete(name="Rank", 
labels= c("First","Second","Third"))+ scale_y_discrete(name="Location", 
breaks =  seq(0, 15, by = 1)) + ggtitle("In-cabin location of top-view ADAS")+
theme(plot.title = element_text(hjust = 0.5))+ labs(fill= "Participant")

dev.off()

png("LocationRankColorSpectralStackplot.png")
ggplot(LongFormRanking, aes(Ranking, fill = Location)) + geom_bar()+
  labs(title = "Stacked Bar Chart", x = "Outlet Location Type")+scale_y_discrete(name="Count of Listings", breaks =  seq(0, 15, by = 1))

dev.off()

######################  refine stacked plot introduce new colour brewer ################################# 
## Not used
colourCount = length(unique(LongFormRanking$Location))
getPalette = colorRampPalette(brewer.pal(11, "RdBu"))


#ggplot(LongFormRanking, aes(x= Ranking, y =ParticipantNr. , fill=Location)) + 
#geom_bar(stat = "identity")+  scale_fill_manual(values = getPalette(colourCount)) +  scale_x_discrete(name="Rank", 
#labels= c("First","Second","Third"))+ scale_y_continuous(name="Count of Listings",
#breaks =  seq(0, 200, by = 10)) + ggtitle("In-cabin location of top-view ADAS")+
#theme(plot.title = element_text(hjust = 0.5))+ labs(fill= "Location")



'
png("RankStackedBarPlotLocationColADj.png")

ggplot(LongFormRanking, aes(x= Ranking ,fill= Location)) + 
geom_bar( position = position_fill())+ scale_fill_manual(values = getPalette(colourCount)) +  
scale_x_discrete(name="Rank",labels= c("First","Second","Third"))+ 
scale_y_continuous(name="Percent of Listing", breaks = seq(0, 1, by = 0.10), labels = percent_format()) +
ggtitle("In-cabin location of top-view ADAS")+
theme(plot.title = element_text(hjust = 0.5))+ 
labs(fill= "Location in Cabin")


dev.off()
#######################################################################################################
#######################################################################################################
'## Not used

LongFormRanking$Xscale<- 1:45

LongFormRanking_TruckPNG<-
#########

FreqTableLocation<-xtabs(~Location+Ranking, LongFormRanking)

FreqFrameLocation <-as.data.frame(FreqTableLocation)

ggplot(LongFormRanking, aes(x= Xscale ,fill= Ranking))+ 
annotation_custom(g,-Inf, Inf, -Inf, Inf)+
scale_x_continuous()+
scale_y_continuous(name="Percent of Listing")


###########
#TruckCabin <- png::readPNG('Appendix_B.png')
g <- rasterGrob(TruckCabin, width=unit(1,"npc"), height=unit(1,"npc"), interpolate = FALSE)



ggplot(LongFormRanking, aes(x= Location ,fill= Ranking)) + annotation_custom(g)+
  geom_bar( position = "dodge")+ 
  scale_fill_manual(values = c("#FFD700", "#C0C0C0", "#cd7f32")) +  
  scale_x_discrete(name="Location")+ 
  scale_y_continuous(name="Frequency", breaks = seq(0, 10, by = 1)) +
  ggtitle("In-cabin location of top-view ADAS")+
  theme(plot.title = element_text(hjust = 0.5))+
  geom_text(stat="count",aes(label = ..count..), position=position_dodge(width=0.9), vjust=+2.6, size = 3, colour = "white") +
  labs(fill= "Location in Cabin")
  
####################### New ranks according to Joost ####################
Rank_1FreqFrame<-subset(FreqFrameLocation,FreqFrameLocation$Ranking  == "Rank1") 
Rank_2FreqFrame<-subset(FreqFrameLocation,FreqFrameLocation$Ranking  == "Rank2") 
Rank_3FreqFrame<-subset(FreqFrameLocation,FreqFrameLocation$Ranking  == "Rank3") 

Rank_1FreqFrame$RankSum1<- Rank_1FreqFrame$Freq*3
Rank_1FreqFrame$RankSum2<- Rank_2FreqFrame$Freq*2
Rank_1FreqFrame$RankSum3<- Rank_3FreqFrame$Freq*1

Rank_1FreqFrame$rowSum<-rowSums(Rank_1FreqFrame[,4:6])

'

####################################  Plot merging procedure #############################################################
####################################                         ############################################################# 


# Date from excel sheet Participant_Data

#MergePorcedure<-data.frame ( partID <- paste("partID", 1:15, sep=""),
MergePorcedure        <- matrix( c(2,2,2,8,4,6,2,1,
                                   3,7,4,1,0,0,0,0,
                                   2,6,2,5,4,1,0,0,
                                   4,3,2,0,0,0,0,0,
                                   2,4,6,1,0,0,0,0,
                                   4,5,6,3,1,0,0,0,
                                   4,2,1,0,0,0,0,0,
                                   7,3,6,2,1,0,0,0,
                                   3,2,6,5,4,1,0,0,
                                   2,4,1,0,0,0,0,0,
                                   9,9,9,9,9,0,0,0,
                                   3,5,6,4,1,0,0,0,
                                   3,6,2,4,2,1,0,0,
                                   6,2,4,1,0,0,0,0,
                                   7,8,2,3,4,2,7,1), nrow = 15,ncol = 8, byrow=T )


partID <- as.factor(1:15)
k<-cbind(partID,as.data.frame(MergePorcedure))

colnames(k)<- c("ID", paste("Step",1:8, sep = " "  ))
mosaicplot(k, color = T, main = "")


####################### Merge procedure counts ######################################################################################################

# setwd("C:/Users/...")


frequencyStep<-matrix( c(0,4,4,3,0,1,2,0,
             0,4,2,2,2,3,0,0,
             2,5,0,2,0,4,1,0,
             3,1,2,2,1,0,1,1,
             3,1,0,4,0,0,0,0,
             3,1,0,0,0,1,0,0,
             0,1,0,0,0,0,1,0,
             2,0,0,0,0,0,0,0
          ), nrow = 8,ncol = 8, byrow=F)



write.table(frequencyStep,"frequencyStep.csv")

frqeuencyStepWithNames<-structure(frequencyStep, dimnames=list(c('Lane change','Traffic observation','Indicator initiation','Acceleration','Class IV mirror use','General mirror use','Shoulder check','Speed Control'), c('Step 1','Step 2',' Step 3', 'Step 4', 'Step 5', 'Step 6', 'Step 7', 'Step 8')))

png("MosaicFreqStepActionBehavMergee.png", width= 900, height = 900)


mosaicplot(frqeuencyStepWithNames,cex.axis = 1.3, las = 2,
 		color="gray59", main="Frequency of mentioned behaviours and tasks by sequence ",
            off = 20,  xlab = "Behaviour and tasks", ylab = "Sequence")
dev.off()



################################# mosaic plot frequency per step ##################################################################

###### alternative mosaic  plot function

#mosaic(frqeuencyStepWithNames,gp_labels=gpar(fontsize=5),las = 2,color=T, main="Frequency of mentioned behaviours and tasks by sequence ",
#        shade = T,highlighting_fill = green , legend=T, rot_labels=c(90,90,0,0), direction = "v")
#
# (frqeuencyStepWithNames)


############# End of Script ##########################

